#
# spec file for package python-oslo.rootwrap
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname oslo.rootwrap
Name:           python-oslo.rootwrap
Version:        5.1.0
Release:        2.3
Summary:        Filtering shell commands to run as root from OpenStack services
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-eventlet >= 0.18.2
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-six >= 1.9.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch
%if 0%{?suse_version}
BuildRequires:  iproute2
%else
BuildRequires:  iproute
%endif

%description
oslo.rootwrap allows fine-grained filtering of shell commands to run as root
from OpenStack services.

%package doc
Summary:        Documentation for OpenStack oslo rootwrap
Group:          Development/Languages/Python
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Documentation for the oslo.rootwrap library.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

# generate html docs
%{__python2} setup.py build_sphinx
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}

%check
export PYTHONPATH=.
%{__python2} setup.py testr

%files
%license LICENSE
%doc ChangeLog README.rst
%{python2_sitelib}/oslo_rootwrap
%{python2_sitelib}/*.egg-info
%{_bindir}/oslo-rootwrap
%{_bindir}/oslo-rootwrap-daemon

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Sep  2 2016 tbechtold@suse.com
- update to version 5.1.0
  * Fix parameters of assertEqual are misplaced
* Wed Aug 10 2016 tbechtold@suse.com
- update to 5.0.0:
  * always allow privsep-helper as a command
  * Add Python 3.5 classifier and venv
  * Updated from global requirements
- Update _service and switch to upstream spec template
* Thu Mar  3 2016 tbechtold@suse.com
- update to 4.1.0:
  * Updated from global requirements
  * Updated from global requirements
  * Remove unused use-syslog-rfc-format option
  * Updated from global requirements
  * Updated from global requirements
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Drop python 2.6 support
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Python 3: encode or decode i/o data of Popen.communicate()
  * Fix Python 3 support for eventlet monkey-patching
  * Fix Python 3 issues in tests
  * No need for Oslo Incubator Sync
  * move usage instructions into main docs
  * docs - Set pbr 'warnerrors' option for doc build
  * Add shields.io version/downloads links/badges into README.rst
  * add pbr-generated release history to the documentation
  * Fix some spelling typo in manual
  * Updated from global requirements
  * Python 3: Don't use BaseException.message attribute
  * Handle renamed executables with KillFilter
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove test-requirements-py3.txt
  * Add tox target to find missing requirements
  * daemon: avoid raising UnboundLocalError to callers
  * Updated from global requirements
  * Updated from global requirements
  * Log that rootwrap was spawned after check
- Adjust Requires according to requirements.txt
* Fri Jun 12 2015 dmueller@suse.com
- update to 2.0.0:
  * Remove oslo namespace package
* Mon Jun  8 2015 tbechtold@suse.com
- update to 1.8.0:
  * Remove run_cross_tests.sh
  * Updated from global requirements
  * Remove mentions of root "tests" package from test_funcional_*
  * Uncap library requirements for liberty
  * Speed up non-daemon rootwrap command line invocation
  * Correct RST syntax errors in README.rst
  * Update to latest hacking
  * Avoid calling sudo just to change users
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.6.0:
  * Remove env changing support in daemon mode
  * Updated from global requirements
  * Updated from global requirements
  * Add bug link to README
- update Requires
* Thu Jan 29 2015 tbechtold@suse.com
- update to version 1.5.0:
  * Add cross-testing script
  * Updated from global requirements
  * Move files out of the namespace package
  * Activate pep8 check that _ is imported
  * Workflow documentation is now in infra-manual
* Thu Jan 15 2015 tbechtold@suse.com
- update to version 1.4.0:
  * Updated from global requirements
  * Updated from global requirements
  * Correct filters examples in README.rst
  * Updated from global requirements
  * Fix exit of subprocess in case it was terminated by signal
  * Updated from global requirements
  * Support building wheels (PEP-427)
  * Updated from global requirements
- Add python_requires to _service
* Mon Sep 22 2014 dmueller@suse.com
- add temporary workaround for non-release version
* Sun Sep 21 2014 tbechtold@suse.com
- update to version 1.3.0:
  * Clean up title on main doc page
  * Initial cut of documentation for oslo.rootwrap
  * Add a short doc to README on how to use daemon mode
  * Fix the bug tracker URL in CONTRIBUTING.rst
  * warn against sorting requirements
  * Updated from global requirements
  * Add daemon mode to benchmark
  * Add an option to run rootwrap as a daemon
  * Refactor common parts from cmd to wrapper
  * Add basic benchmark
  * Remove sys.path modification
  * Move test requirement coverage into tox.ini
  * Enabled hacking check H305
  * Continue on failure of leaf filters of chaining filters
- Adjust python-six Requires version according to requirements.txt
* Tue Jul 29 2014 dmueller@suse.com
- update to 1.3.0a1:
  * Let tests pass on distros where "ip" is in /bin
  * Bump hacking to 0.9.x series
  * Avoid usage of mutables as default args
  * Simplify the flow in RegExpFilter
  * Add ChainingRegExpFilter for prefix utilities
  * Fix Python 3 support, add functional test
  * Fix import grouping
  * Remove unused variable 'command'
  * Run py33 test env before others
* Wed Apr  9 2014 dmueller@suse.com
- update to 1.2.0:
  * Avoid matching ip -s netns exec in IpFilter
  * Don't use system pip things in tox
  * Add Python 3 trove classifiers
  * To honor RFC5424 add use_syslog_rfc_format config option
  * Trivial changes from oslo-incubator
* Mon Mar 24 2014 dmueller@suse.com
- reduce test requires
* Thu Feb 13 2014 dmueller@suse.com
- remove dependency on oslo.sphinx
* Tue Feb 11 2014 speilicke@suse.com
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Fri Feb  7 2014 dmueller@suse.com
- update to 1.1.0:
  * remove entry points, in the packages now
* Thu Jan 16 2014 dmueller@suse.com
- clean up requires
* Thu Dec 12 2013 dmueller@suse.com
- Initial package (1.0.0)
